import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_svg/svg.dart';
import 'package:npay_component/npay_component.dart';
import 'package:npay_component/styles/colors.dart';

class SearchBar extends StatefulWidget {
  final TextEditingController controller;
  final List<TextInputFormatter> inputFormatters;
  final Function(String keyword) onSearch;
  final bool autoFocus;
  final String hintText;

  SearchBar(
      {Key key,
      @required this.controller,
      this.inputFormatters,
      @required this.onSearch,
      this.autoFocus = false, this.hintText})
      : super(key: key);

  @override
  _SearchBarState createState() => _SearchBarState();
}

class _SearchBarState extends State<SearchBar> {
  final _focusNode = FocusNode();
  bool _showClear = false;
  bool _isFocus = false;

  @override
  void initState() {
    _focusNode.addListener(() {
      setState(() {
        _showClear = _focusNode.hasFocus && widget.controller.text.isNotEmpty;
        _isFocus = _focusNode.hasFocus;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 36,
      child: Stack(
        alignment: Alignment.centerRight,
        children: [
          TextFormField(
            controller: widget.controller,
            focusNode: _focusNode,
            autofocus: widget.autoFocus,
            inputFormatters: widget.inputFormatters,
            style: TextStyle(
                color: titleTextColor,
                fontSize: 12,
                fontWeight: FontWeight.w400),
            cursorColor: titleTextColor,
            textAlignVertical: TextAlignVertical.center,
            onChanged: (v) {
              setState(() {
                _showClear = v.isNotEmpty;
              });
            },
            onFieldSubmitted: widget.onSearch,
            textInputAction: TextInputAction.search,
            decoration: InputDecoration(
                isDense: true,
                filled: true,
                contentPadding: EdgeInsets.fromLTRB(0, 8, 40, 8),
                border: _transparentBorder(),
                enabledBorder: _transparentBorder(),
                focusedBorder: _transparentBorder(),
                errorBorder: _transparentBorder(),
                disabledBorder: _transparentBorder(),
                prefixIcon: Padding(
                  padding:
                      const EdgeInsets.symmetric(horizontal: 16, vertical: 11),
                  child: Icon(Icons.search,
                      color: !_isFocus ? bodyTextColor : titleTextColor,
                      size: 16),
                ),
                hintStyle: TextStyle(color: inactiveIconColor),
                hintText: widget.hintText,
                fillColor: toolBarBg2Color),
          ),
          Visibility(
            visible: _showClear,
            child: Padding(
              padding: const EdgeInsets.all(10.0),
              child: Container(
                width: 16,
                height: 16,
                child: IconButton(
                  padding: const EdgeInsets.all(0),
                  onPressed: () {
                    setState(() {
                      widget.controller.clear();
                      _showClear = false;
                    });
                  },
                  icon: SvgPicture.asset('assets/icons/clear.svg',
                      fit: BoxFit.contain,
                      color: Colors.black,
                      package: package),
                ),
              ),
            ),
          )
        ],
      ),
    );
  }

  _transparentBorder() {
    return OutlineInputBorder(
      borderSide: BorderSide(color: Colors.transparent, width: 0),
      borderRadius:
      const BorderRadius.all(const Radius.circular(32.0)),
    );
  }
}
