import 'package:flutter/material.dart';
import 'package:npay_component/styles/colors.dart';
import 'package:npay_component/styles/font_scale.dart';

class NpDialog extends StatefulWidget {
  final String title;
  final String content;
  final String textBtnGreen;
  final String textBtnWhite;
  final VoidCallback btnGreenClick;
  final VoidCallback btnWhiteClick;
  final bool isPop;

  const NpDialog(
      {Key key,
      @required this.title,
      @required this.content,
      this.isPop = true,
      @required this.textBtnGreen,
      @required this.textBtnWhite,
      this.btnGreenClick,
      this.btnWhiteClick})
      : super(key: key);

  @override
  _NpDialogState createState() => _NpDialogState();
}

class _NpDialogState extends State<NpDialog> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    // FocusScope.of(context).requestFocus(FocusNode());
    return Dialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(12),
      ),
      elevation: 0.0,
      backgroundColor: Colors.white,
      insetPadding: EdgeInsets.all(16),
      child: WillPopScope(
          child: dialogContent(),
          onWillPop: () async {
            return false;
          }),
    );
  }

  dialogContent() {
    return Padding(
        padding: EdgeInsets.all(16),
        child: Wrap(
          children: [
            Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Text(widget.title).semiBold14(),
                SizedBox(height: 12),
                Text(widget.content).regularContext12(),
                SizedBox(height: 24),
                _viewButton()
              ],
            ),
          ],
        ));
  }

  ButtonStyle getButtonStyle(bool isGreenButton) {
    return TextButton.styleFrom(
        padding: EdgeInsets.symmetric(vertical: 10, horizontal: 35),
        shape: const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(8))),
        backgroundColor: isGreenButton ? Color(0xFF15AE62) : Color(0xFFF4F6FA));
  }

  _viewButton() {
    return Row(
      children: [
        Expanded(
          child: Container(
            height: 36,
            child: TextButton(
              style: getButtonStyle(false),
              child: Text(widget.textBtnWhite ?? "").semiBold12(color: mainGreenColor),
              onPressed: widget.textBtnWhite != null
                  ? () {
                      // NPNavigator().pop();
                      widget.btnWhiteClick();
                    }
                  : () {},
            ),
          ),
        ),
        SizedBox(width: 8),
        Expanded(
          child: Container(
            height: 36,
            child: TextButton(
              style: getButtonStyle(true),
              child: Text(widget.textBtnGreen ?? "").semiBold12(color: whiteColor),
              onPressed: widget.textBtnGreen != null
                  ? () {
                      widget.btnGreenClick();
                    }
                  : () {},
            ),
          ),
        )
      ],
    );
  }
}
