import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:npay_component/npay_component.dart';
import 'package:npay_component/styles/colors.dart';
import 'package:npay_component/styles/styles.dart';

class TextFieldPassword extends StatefulWidget {
  final TextEditingController controller;
  final int maxLength;
  final String labelText;
  final String textError;
  final String hintText;
  final bool disable;
  final TextInputAction textInputAction;
  final TextCapitalization textCapitalization;
  final Function onTap;
  final Function unFocus;
  final FocusNode focusNode;
  final List<TextInputFormatter> inputFormatters;
  final TextInputType keyboardType;
  final Function(String text) onChange;
  final bool autoFocus;
  final Color color;
  final bool showClear;
  final bool showEye;
  final Function onTapClear;
  final bool autocorrect;

  const TextFieldPassword({
    @required this.controller,
    this.maxLength = 100,
    this.keyboardType = TextInputType.text,
    this.inputFormatters,
    @required this.onChange,
    this.labelText = '',
    this.textError = '',
    this.disable = false,
    this.onTap,
    this.textInputAction = TextInputAction.done,
    this.textCapitalization = TextCapitalization.none,
    this.hintText = '',
    this.autoFocus = false,
    this.color = Colors.white,
    this.unFocus,
    this.showClear = true,
    this.showEye = true,
    this.focusNode,
    this.onTapClear,
    this.autocorrect = false,
  });

  @override
  _TextFieldPasswordState createState() => _TextFieldPasswordState();
}

class _TextFieldPasswordState extends State<TextFieldPassword> {
  FocusNode _focusNode;
  bool _isShowLabel = false;
  bool _isObscureText = true;
  bool _clickedClear = false;

  @override
  void initState() {
    _focusNode = widget.focusNode ?? FocusNode();
    _focusNode.addListener(() {
      if (!_focusNode.hasFocus) if (widget.unFocus != null) widget.unFocus();
      setState(() {
        _isShowLabel = _focusNode.hasFocus || widget.controller.text.isNotEmpty;
      });
    });
    super.initState();
  }

  @override
  void dispose() {
    _focusNode.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.start,
      children: <Widget>[
        Theme(
          data: Theme.of(context).copyWith(focusColor: Colors.transparent),
          child: InkWell(
            onTap: () {
              if (widget.onTap != null) widget.onTap();
              setState(() {});
              FocusScope.of(context).requestFocus(_focusNode);
            },
            child: Stack(
              alignment: Alignment.centerRight,
              children: [
                Container(
                  height: 56,
                  decoration: BoxDecoration(
                      // Color disable input
                      color: widget.disable ? mainBgColor : widget.color,
                      borderRadius: BorderRadius.all(Radius.circular(10)),
                      border: Border.all(color: Colors.transparent, width: 0)),
                  child: Stack(
                    alignment: Alignment.bottomCenter,
                    children: [
                      Column(
                        crossAxisAlignment: CrossAxisAlignment.start,
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          Visibility(
                            visible: widget.labelText.isNotEmpty,
                            child: Column(
                              children: [
                                SizedBox(height: _isShowLabel ? 2 : 1),
                                _labelInput(),
                                SizedBox(height: _isShowLabel ? 2 : 0),
                              ],
                            ),
                          ),
                          _inputField(),
                        ],
                      ),
                      _dividerInput(),
                    ],
                  ),
                ),
                Visibility(
                  visible: ((_focusNode.hasFocus &&
                              widget.controller.text.isNotEmpty) ||
                          widget.disable) &&
                      !widget.disable,
                  child: !_clickedClear ? _iconAction() : Container(),
                ),
              ],
            ),
          ),
        ),
        SizedBox(height: widget.textError.isNotEmpty ? 4 : 0),
        _buildErrorText(),
      ],
    );
  }

  Widget _buildErrorText() {
    return Padding(
      padding: const EdgeInsets.symmetric(horizontal: 16),
      child: Text(widget.textError,
          maxLines: 2, overflow: TextOverflow.ellipsis, style: errorTextField),
    );
  }

  Widget _dividerInput() {
    return Visibility(
      visible: _focusNode.hasFocus,
      child: Padding(
        padding: const EdgeInsets.symmetric(horizontal: 16),
        child: Container(
          color: widget.textError.isNotEmpty ? dangerColor : mainGreenColor,
          width: double.infinity,
          height: 2,
        ),
      ),
    );
  }

  Widget _inputField() {
    return Container(
      height: 20,
      child: Center(
        child: TextFormField(
          textInputAction: widget.textInputAction,
          textCapitalization: widget.textCapitalization,
          focusNode: _focusNode,
          autofocus: widget.autoFocus,
          enabled: !widget.disable,
          readOnly: widget.disable,
          textAlignVertical: TextAlignVertical.center,
          style: TextStyle(
              fontSize: 14,
              color: widget.disable ? inactiveIconColor : Colors.black,
              height: 1.2),
          controller: widget.controller,
          maxLength: widget.maxLength,
          keyboardType: widget.keyboardType,
          maxLines: 1,
          obscureText: _isObscureText,
          obscuringCharacter: '*',
          autofillHints: null,
          onChanged: (text) {
            widget.onChange(text);
            setState(() {
              _clickedClear = false;
            });
          },
          autocorrect: widget.autocorrect,
          onFieldSubmitted: (term) {
            if (widget.textInputAction == TextInputAction.next) {
              FocusScope.of(context).nextFocus();
            } else if (widget.textInputAction == TextInputAction.done) {
              FocusScope.of(context).requestFocus(FocusNode());
            }
          },
          inputFormatters: widget.inputFormatters,
          cursorColor: Colors.black,
          decoration: InputDecoration(
            contentPadding: EdgeInsets.only(
                left: 16, right: widget.showClear && widget.showEye ? 85 : 45),
            hintText: widget.labelText.isEmpty
                ? widget.hintText
                : _isShowLabel
                    ? widget.hintText
                    : widget.labelText,
            counterText: '',
            hintStyle: hintStyle,
            focusedBorder: OutlineInputBorder(
              borderSide: BorderSide(color: Colors.transparent, width: 0),
            ),
            enabledBorder: OutlineInputBorder(
              borderSide: BorderSide(color: Colors.transparent, width: 0),
            ),
            disabledBorder: OutlineInputBorder(
              borderSide: BorderSide(color: Colors.transparent, width: 0),
            ),
          ),
        ),
      ),
    );
  }

  Widget _labelInput() {
    return AnimatedOpacity(
        duration: Duration(milliseconds: 200),
        opacity: (_isShowLabel || widget.disable) ? 1 : 0,
        child: Visibility(
          visible: _isShowLabel || widget.disable,
          child: Container(
            height: 16,
            child: Padding(
              padding: const EdgeInsets.only(left: 16, right: 16),
              child: Text(
                widget.labelText,
                maxLines: 1,
                overflow: TextOverflow.ellipsis,
                style: styleLabelTextField,
              ),
            ),
          ),
        ));
  }

  Widget _iconAction() => Container(
        child: Padding(
          padding: const EdgeInsets.only(right: 16),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.end,
            children: [
              Visibility(
                visible: widget.showClear,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: [
                    UnconstrainedBox(
                      child: Container(
                        width: 17,
                        height: 17,
                        decoration: BoxDecoration(
                            shape: BoxShape.circle, color: inactiveIconColor),
                        child: InkWell(
                          onTap: () {
                            setState(() {
                              widget.controller.clear();
                              _clickedClear = true;
                              if (widget.onTapClear != null)
                                widget.onTapClear();
                            });
                          },
                          child: Icon(
                            Icons.clear,
                            color: Colors.white,
                            size: 10,
                          ),
                        ),
                      ),
                    ),
                    Padding(
                        padding: const EdgeInsets.symmetric(horizontal: 10),
                        child: Container(
                          width: 1,
                          height: 18,
                          color: borderDefault,
                        )),
                  ],
                ),
              ),
              UnconstrainedBox(
                child: Visibility(
                  visible: widget.showEye,
                  child: InkWell(
                    onTap: () {
                      setState(() {
                        _isObscureText = !_isObscureText;
                      });
                    },
                    child: SvgPicture.asset(
                      _isObscureText
                          ? 'assets/icons/view.svg'
                          : 'assets/icons/hide.svg',
                      width: 20,
                      height: 20,
                      package: package,
                    ),
                  ),
                ),
              ),
            ],
          ),
        ),
      );
}
