import 'package:flutter/material.dart';
import 'package:flutter_styled_toast/flutter_styled_toast.dart';
import 'package:npay_component/styles/colors.dart';
import 'package:npay_component/styles/font_scale.dart';

void showToastSuccess(BuildContext context,
    {@required String title, Duration duration}) {
  _baseToast(context, title: title, colorBackground: successColor);
}

void showToastWarning(BuildContext context,
    {@required String title, Duration duration}) {
  _baseToast(context, title: title, colorBackground: waringColor);
}

void showToastDanger(BuildContext context,
    {@required String title, Duration duration}) {
  _baseToast(context, title: title, colorBackground: dangerColor);
}

void showToastInfo(BuildContext context,
    {@required String title, Duration duration}) {
  _baseToast(context, title: title, colorBackground: infoColor);
}

void _baseToast(BuildContext context,
    {@required String title,
    @required Color colorBackground,
    Duration duration = const Duration(seconds: 5)}) {
  showToastWidget(
      ConstrainedBox(
        constraints: BoxConstraints(minHeight: 32),
        child: Container(
          padding: EdgeInsets.only(left: 18.0),
          margin: EdgeInsets.symmetric(horizontal: 40.0),
          decoration: ShapeDecoration(
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(32.0),
            ),
            color: colorBackground,
          ),
          child: Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            mainAxisSize: MainAxisSize.max,
            children: [
              Expanded(
                child: Padding(
                    padding: const EdgeInsets.symmetric(vertical: 8),
                    child: Text(title, maxLines: 2).semiBold12(color: whiteColor)),
              ),
              Padding(
                padding: const EdgeInsets.only(right: 8),
                child: Container(
                  width: 17,
                  height: 17,
                  decoration: BoxDecoration(
                      shape: BoxShape.circle, color: Colors.white),
                  child: InkWell(
                    onTap: () => ToastManager().dismissAll(showAnim: true),
                    child: Icon(
                      Icons.clear,
                      color: colorBackground,
                      size: 10,
                    ),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
      context: context,
      isIgnoring: false,
      duration: duration,
      position: StyledToastPosition(align: Alignment.topCenter));
}
